# Retrigen


[![PyPI](https://img.shields.io/pypi/v/retrigen.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/retrigen)][pypi status]
[![documentation](https://github.com/KennethEnevoldsen/retrigen/actions/workflows/documentation.yml/badge.svg)][documentation]
[![Tests](https://github.com/KennethEnevoldsen/retrigen/actions/workflows/tests.yml/badge.svg)][tests]
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)]([ruff])


[pypi status]: https://pypi.org/project/retrigen/
[documentation]: https://KennethEnevoldsen.github.io/retrigen/
[tests]: https://github.com/KennethEnevoldsen/retrigen/actions?workflow=Tests
[ruff]: https://github.com/astral-sh/ruff


<!-- start short-description -->

TODO: Add a short description of the project.

<!-- end short-description -->



# 💬 Where to ask questions

| Type                           |                        |
| ------------------------------ | ---------------------- |
| 📚 **FAQ**                      | [FAQ]                  |
| 🚨 **Bug Reports**              | [GitHub Issue Tracker] |
| 🎁 **Feature Requests & Ideas** | [GitHub Issue Tracker] |
| 👩‍💻 **Usage Questions**          | [GitHub Discussions]   |
| 🗯 **General Discussion**       | [GitHub Discussions]   |

[Installation]: https://KennethEnevoldsen.github.io/retrigen/installation.html
[Tutorials]: https://KennethEnevoldsen.github.io/retrigen/tutorials.html
[API Reference]: https://KennethEnevoldsen.github.io/retrigen/references.html
[FAQ]: https://KennethEnevoldsen.github.io/retrigen/faq.html
[github issue tracker]: https://github.com/KennethEnevoldsen/retrigen/issues
[github discussions]: https://github.com/KennethEnevoldsen/retrigen/discussions



